USE [OpenData]
GO

--We can get estimated execution plans like normal.
SET SHOWPLAN_XML ON
GO

EXECUTE [dbo].[IncidentInMemory_GetIncidentInMemoryByLocalCrimeReportingCode]
	@LocalCrimeReportingCode = 'TEST1';

GO

SET SHOWPLAN_XML OFF
GO

--By default, no stats get shown.
SELECT
	st.objectid, 
	object_name(st.objectid) as 'object name', 
	SUBSTRING(st.text, (qs.statement_start_offset/2) + 1, ((qs.statement_end_offset-qs.statement_start_offset)/2) + 1) as 'query text', 
	qs.creation_time,
	qs.last_execution_time,
	qs.execution_count,
	qs.total_worker_time,
	qs.last_worker_time,
	qs.min_worker_time,
	qs.max_worker_time,
	qs.total_elapsed_time,
	qs.last_elapsed_time,
	qs.min_elapsed_time,
	qs.max_elapsed_time
FROM sys.dm_exec_query_stats qs 
	CROSS APPLY sys.dm_exec_sql_text(sql_handle) st
	INNER JOIN sys.sql_modules sm
		ON st.objectid = sm.object_id
WHERE
	st.dbid = DB_ID()
	AND sm.uses_native_compilation = 1
ORDER BY
	qs.total_worker_time DESC;

GO

--Turn on stats gathering...

--Turning this on lets us use sys.dm_exec_query stats.
--This reduces query performance, so best practice is to turn it on 
--	during debugging and turn it off afterward.
DECLARE
	@DatabaseID INT = DB_ID(),
	@ObjectID BIGINT = OBJECT_ID('dbo.IncidentInMemory_GetIncidentInMemoryByLocalCrimeReportingCode');

EXEC [sys].[sp_xtp_control_query_exec_stats] 
	@new_collection_value = 1, 
	@database_id = @DatabaseID,
	@xtp_object_id = @ObjectID;

GO

--Procedure stats are off by default.
SELECT
	object_id,
	object_name(object_id) as 'object name',
	cached_time,
	last_execution_time,
	execution_count,
	total_worker_time,
	last_worker_time,
	min_worker_time,
	max_worker_time,
	total_elapsed_time,
	last_elapsed_time,
	min_elapsed_time,
	max_elapsed_time 
FROM sys.dm_exec_procedure_stats
WHERE 
	database_id = db_id() 
	AND object_id IN
	(
		SELECT object_id 
		FROM sys.sql_modules 
		WHERE uses_native_compilation=1
	)
ORDER BY
	total_worker_time DESC;

--Turning this on lets us use sys.dm_exec_procedure_stats.
--This turns on stats collection for ALL natively compiled stored procedures
--	across the entire instance.
--This reduces query performance, so best practice is to turn it on
--	during debugging and turn it off afterward.

EXEC [sys].[sp_xtp_control_proc_exec_stats] 
	@new_collection_value = 1;


GO

--Now turn them back off...
EXEC [sys].[sp_xtp_control_proc_exec_stats] 
	@new_collection_value = 0;
GO
DECLARE
	@DatabaseID INT = DB_ID(),
	@ObjectID BIGINT = OBJECT_ID('dbo.IncidentInMemory_GetIncidentInMemoryByLocalCrimeReportingCode');

EXEC [sys].[sp_xtp_control_query_exec_stats] 
	@new_collection_value = 0, 
	@database_id = @DatabaseID,
	@xtp_object_id = @ObjectID;
